@@ -1,10 +1,10 @@
 #!/usr/bin/env perl
-# $Id: get_ancestor_terms.pl 2013-09-29 erick.antezana $
+# $Id: get_ancestor_terms.pl 2015-10-29 erick.antezana $
 #
 # Script  : get_ancestor_terms.pl
 # Purpose : Collects the ancestor terms from a given term in the given OBO ontology
 # Usage   : get_ancestor_terms.pl my_ontology.obo term_id > ancestors.txt
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -17,10 +17,34 @@ use warnings;
 
 use OBO::Parser::OBOParser;
 
-my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
+use Getopt::Long;
 
-my $term_id = shift(@ARGV);
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	't=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file    = $opts{f};
+my $term_id = $opts{t};
+
+unless ($file and $term_id) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Collects the ancestor terms from a given term in the given OBO ontology.\n";
+	print "\tusage      : get_ancestor_terms.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 OBO input file\n";
+	print "\t\t-t 	 term ID\n";
+	print "\texample:\n";
+	print "\t\tperl get_ancestor_terms.pl -f go.obo -t GO:0000234\n";
+	exit;
+}
+
+my $my_parser = OBO::Parser::OBOParser->new();
+my $ontology = $my_parser->work($file);
 
 foreach my $term (@{$ontology->get_ancestor_terms($ontology->get_term_by_id($term_id))}) {
 	print $term->id();
@@ -46,7 +70,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
