@@ -1,10 +1,10 @@
 #!/usr/bin/env perl
-# $Id: get_lowest_common_ancestor.pl 2013-10-16 erick.antezana $
+# $Id: get_lowest_common_ancestor.pl 2015-10-16 erick.antezana $
 #
 # Script  : get_lowest_common_ancestor.pl
 # Purpose : Gets the lowest common ancestor (LCA) of two terms in a given OBO ontology.
 # Usage   : get_lowest_common_ancestor.pl my_ontology.obo term_id1 term_id2 > lca.txt
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same relationships as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -17,16 +17,43 @@ use warnings;
 
 use OBO::Parser::OBOParser;
 
+use Getopt::Long;
+
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	'a=s{1,1}',
+	'b=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file      = $opts{f};
+my $taxon1_id = $opts{a};
+my $taxon2_id = $opts{b};
+
+unless ($file and $taxon1_id and $taxon2_id) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Get the lowest common ancestor (LCA) of two terms in a given OBO ontology.\n";
+	print "\tusage      : get_lowest_common_ancestor.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 OBO input file\n";
+	print "\t\t-a 	 term 1 ID\n";
+	print "\t\t-b 	 term 2 ID\n";
+	print "\texample:\n";
+	print "\t\tperl get_lowest_common_ancestor.pl -f go.obo -t GO:0000234 -t GO:0000111\n";
+	exit;
+}
+
 ###############################################################################
 
 my $my_parser    = OBO::Parser::OBOParser->new();
-my $my_ncbi_onto = $my_parser->work(shift);
+my $my_ncbi_onto = $my_parser->work($file);
 
 my $r = 'is_a';
 
 my $root_id   = @{$my_ncbi_onto->get_root_terms()}[0]; # only one root term
-my $taxon1_id = shift;
-my $taxon2_id = shift;
 
 my $stop = OBO::Util::Set->new();
 $stop->add($root_id);
@@ -60,7 +87,7 @@ __END__
 
 =head1 NAME
 
-get_lowest_common_ancestor.pl - the lowest common ancestor (LCA) of two terms in a given OBO ontology.
+get_lowest_common_ancestor.pl - Get the lowest common ancestor (LCA) of two terms in a given OBO ontology.
 
 =head1 DESCRIPTION
 
@@ -75,7 +102,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
