@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: get_subontology_from.pl 2013-09-29 erick.antezana $
+# $Id: get_subontology_from.pl 2015-10-29 erick.antezana $
 #
 # Script  : get_subontology_from.pl
 # Purpose : Given an OBO-formatted ontology (such as the Gene Ontology), this script 
@@ -7,7 +7,7 @@
 #           This script can easily be adapted to get such a sub-ontology (branch) taking into
 #           account the name (or synonym) of a given term.
 # Usage   : get_subontology_from.pl input_ontology.obo term_id > sub_ontology.obo
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -19,10 +19,35 @@ use warnings;
 use Carp;
 use OBO::Parser::OBOParser;
 
-my $my_parser     = OBO::Parser::OBOParser->new();
-my $my_large_onto = $my_parser->work(shift @ARGV);
+use Getopt::Long;
 
-my $new_root      = $my_large_onto->get_term_by_id(shift @ARGV);
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	't=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file    = $opts{f};
+my $term_id = $opts{t};
+
+unless ($file and $term_id) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Extracts a subontology (in OBO format) of a given ontology having as root the given term ID.\n";
+	print "\tusage      : get_subontology_from.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 OBO input file\n";
+	print "\t\t-t 	 term ID\n";
+	print "\texample:\n";
+	print "\t\tperl get_subontology_from.pl -f go.obo -t GO:0000234\n";
+	exit;
+}
+my $my_parser = OBO::Parser::OBOParser->new();
+my $my_large_onto = $my_parser->work($file);
+
+my $new_root      = $my_large_onto->get_term_by_id($term_id);
 die "The term, you have asked as being the new root, does not exist!\n" if (!$new_root);
 my $sub_ontology  = $my_large_onto->get_subontology_from($new_root);
 $sub_ontology->export('obo', \*STDOUT);
@@ -52,7 +77,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
