@@ -1,12 +1,12 @@
 #!/usr/bin/env perl
-# $Id: get_term_id_vs_term_namespace.pl 2013-09-29 erick.antezana $
+# $Id: get_term_id_vs_term_namespace.pl 2015-10-29 erick.antezana $
 #
 # Script  : get_term_id_vs_term_namespace.pl
 # Purpose : Generates a flat file with two columns (TAB separated) with the 
 #           get_term_id and term_namespace (e.g. biological process) from the elements 
 #           of the given OBO ontology.
 # Usage   : get_term_id_vs_term_namespace.pl my_ontology.obo > get_term_id_vs_term_namespace.txt
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -19,8 +19,30 @@ use warnings;
 
 use OBO::Parser::OBOParser;
 
+use Getopt::Long;
+
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file    = $opts{f};
+
+unless ($file) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Gets the term IDs and its namespaces in a given ontology.\n";
+	print "\tusage      : get_term_id_vs_term_namespace.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 OBO input file\n";
+	print "\texample:\n";
+	print "\t\tperl get_term_id_vs_term_namespace.pl -f go.obo\n";
+	exit;
+}
 my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
+my $ontology = $my_parser->work($file);
 
 foreach my $term (sort {$a->id() cmp $b->id()} @{$ontology->get_terms()}) {
 	print $term->id(), "\t", $term->namespace(), "\n" if (defined $term->namespace()); 
@@ -46,7 +68,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
