@@ -1,10 +1,10 @@
 #!/usr/bin/env perl
-# $Id: get_terms_by_name.pl 2013-09-29 erick.antezana $
+# $Id: get_terms_by_name.pl 2015-10-29 erick.antezana $
 #
 # Script  : get_terms_by_name.pl
 # Purpose : Find all the terms in a given ontology that have a given string in their names.
 # Usage   : get_terms_by_name.pl my_ontology.obo name_string > ids_and_terms.txt
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -13,11 +13,36 @@
 
 use OBO::Parser::OBOParser;
 
-my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology  = $my_parser->work(shift @ARGV);
-my $name      = shift @ARGV;
+use Getopt::Long;
 
-my $my_terms  = $ontology->get_terms_by_name($name);
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	't=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file    = $opts{f};
+my $term_name = $opts{t};
+
+unless ($file and $term_name) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Find all the terms in a given ontology that have a given string in their names.\n";
+	print "\tusage      : get_terms_by_name.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 OBO input file\n";
+	print "\t\t-t 	 term name\n";
+	print "\texample:\n";
+	print "\t\tperl get_terms_by_name.pl -f go.obo -t nucleous\n";
+	exit;
+}
+
+my $my_parser = OBO::Parser::OBOParser->new();
+my $ontology = $my_parser->work($file);
+
+my $my_terms  = $ontology->get_terms_by_name($term_name);
 if ($my_terms) {
 	my @terms_arr = $my_terms->get_set();
 	foreach my $t (sort {$a->id() cmp $b->id()} @terms_arr) {
@@ -47,7 +72,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
