@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: goa2rdf.pl 2014-11-11 erick.antezana $
+# $Id: goa2rdf.pl 2015-10-11 erick.antezana $
 #
 # Script  : goa2rdf.pl
 # Purpose : Generates a simple RDF graph from a given GOA file.
@@ -10,7 +10,7 @@
 #  			2. File handle for writing RDF: STDOUT
 # 			3. base URI (default: 'http://www.semantic-systems-biology.org/')
 # 			4. namespace (default: 'SSB')
-# License : Copyright (c) 2006-2014 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -23,13 +23,35 @@ use warnings;
 
 use OBO::APO::GoaToRDF;
 
-my $input_file = shift(@ARGV);
+use Getopt::Long;
+
+my %opts = ();
+GetOptions (\%opts,
+	'f=s{1,1}',
+	'help|h')
+or die("Error in command line arguments, ask for help: -h\n");
+
+my $file    = $opts{f};
+
+unless ($file) {print_help()};
+
+sub print_help {
+	print "\n";
+	print "\tdescription: Generates a simple RDF graph from a given GOA file.\n";
+	print "\tusage      : goa2rdf.pl [options]\n";
+	print "\toptions    :\n";
+	print "\t\t-f  	 GOA input file\n";
+	print "\texample:\n";
+	print "\t\tperl goa2rdf.pl -f file.goa\n";
+	exit;
+}
+
 my $goa2rdf = OBO::APO::GoaToRDF->new();
 
 my $file_handle = \*STDOUT;
 my $base        = 'http://www.semantic-systems-biology.org/';
 my $ns          = 'SSB';
-$file_handle    = $goa2rdf->work($input_file, $file_handle, $base, $ns);
+$file_handle    = $goa2rdf->work($file, $file_handle, $base, $ns);
 
 exit 0;
 
@@ -49,7 +71,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2014 by Erick Antezana
+Copyright (c) 2006-2015 by Erick Antezana. All rights reserved.
 
 This script is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
